unit regedit;
{
********************************************************************************
* TRegistryEdit v2.0                                                           *
********************************************************************************
* NOTE: This component differs slightly from previous versions in that I have  *
*       made it more "compatible" with TIniFile and TRegIniFile. The functions *
*       now work in a similar manner.                                          *
********************************************************************************
* Author: Raoul Snyman                                                         *
* ---------------------------------------------------------------------------- *
* E-Mail: saturnlaboratories@eject.co.za                                       *
* ---------------------------------------------------------------------------- *
* Copyright: 1999-2003 Saturn Laboratories.                                   *
* ---------------------------------------------------------------------------- *
* Description: A simple wrapper component for the TRegistry object, with some  *
*              procedures and functions to read and write to the registry      *
*              without having to deal with opening and closing the keys        *
*              manually.                                                       *
********************************************************************************
* This component is FREEWARE.                                                  *
* It may be used for commercial purposes on the condition that you give me     *
* credit.                                                                      *
* If used in freeware, it is not necessary although it would be appreciated.   *
* If you modify this code, please send me an e-mail with a copy of the code    *
* attached, letting me know what it was that you changed/modified/added.       *
********************************************************************************
* PROCEDURES AND FUNCTIONS IN THIS COMPONENT:                                  *
* ---------------------------------------------------------------------------- *
* Value Writing:                                                               *
*                                                                              *
*  procedure WriteString(DataName, DataValue: string);                         *
*    Writes string "DataValue" to "DataName" using the current key contained   *
*    in FRegistryKey and FRegKey. If "DataName" does not exist, it will be     *
*    automatically created.                                                    *
*                                                                              *
*  procedure WriteInteger(DataName: string; DataValue: integer);               *
*    Writes integer "DataValue" to "DataName" using the same method as above.  *
*                                                                              *
*  procedure WriteBoolean(DataName: string; DataValue: boolean);               *
*    Writes boolean "DataValue" to "DataName" using the same method as above.  *
*                                                                              *
*  procedure WriteDateTime(DataName: string; DataValue: TDateTime);            *
*    Writes a Delphi DateTime "DataValue" to "DataName" using the same method  *
*    as above.                                                                 *
*                                                                              *
* ---------------------------------------------------------------------------- *
* Value Reading:                                                               *
*                                                                              *
*  function ReadString(DataName, Default: string): string;                     *
*    Reads a string from "DataName" using the current key contained in         *
*    FRegistryKey and FRegKey. If no value is found, "Default" is returned.    *
*                                                                              *
*  function ReadInteger(DataName: string; Default: integer): integer;          *
*    Reads an integer from "DataName" using the same method as above.          *
*                                                                              *
*  function ReadBoolean(DataName: string; Default: boolean): boolean;          *
*    Reads a boolean from "DataName" using the same method as above.           *
*                                                                              *
*  function ReadDateTime(DataName: string; Default: TDateTime): TDateTime;     *
*    Reads a Delphi DateTime from "DataName" using the same method as above.   *
*                                                                              *
* ---------------------------------------------------------------------------- *
* Other:                                                                       *
*                                                                              *
*  function DeleteKey(Key: string): boolean;                                   *
*    Deletes the Registry key "Key" and returns True if successful.            *
*                                                                              *
*  function DeleteDataValue(DataName: string): boolean;                        *
*    Deletes the DataValue of the DataName set in "DataValue" using the Key    *
*    contained in FRegistryKey and FRegKey and returns True if successful.     *
*                                                                              *
*  function KeyExists(Key: string): boolean;                                   *
*    Checks to see if the Key in "Key" exists and returns "True" if it does.   *
*                                                                              *
*  function DataValueExists(DataName: string): boolean;                        *
*    Checks to see if the DataValue of DataName held in "DataName" exists,     *
*    returning "True" if so.                                                   *
*                                                                              *
********************************************************************************
}

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls,
  Forms, Dialogs, Registry;

type
  TRootKey = (rkAllUsers, rkCurrentUser, rkLocalMachine,
              rkClassesRoot, rkCurrentConfig, rkDynData);
  TRegistryEdit = class(TComponent)
  private
    { Private declarations }
    FRootKey: TRootKey;
    FRegistryKey: HKEY;
    FRegKey: string;
    procedure SetRootKey(RootKey: TRootKey);
  protected
    { Protected declarations }
  public
    { Public declarations }
    procedure WriteString(DataName: string; DataValue: string);
    procedure WriteInteger(DataName: string; DataValue: integer);
    procedure WriteBoolean(DataName: string; DataValue: boolean);
    procedure WriteDateTime(DataName: string; DataValue: TDateTime);
    function ReadString(DataName, Default: string): string;
    function ReadInteger(DataName: string; Default: integer): integer;
    function ReadBoolean(DataName: string; Default: boolean): boolean;
    function ReadDateTime(DataName: string; Default: TDateTime): TDateTime;
    function DeleteKey(Key: string): boolean;
    function DeleteDataValue(DataValue: string): boolean;
    function KeyExists(Key: string): boolean;
    function DataValueExists(DataValue: string): boolean;
  published
    { Published declarations }
    property RootKey: TRootKey read FRootKey write SetRootKey;
    property RegKey: string read FRegKey write FRegKey;
  end;

procedure Register;

implementation

procedure Register;
begin
  RegisterComponents('Additional', [TRegistryEdit]);
end;

procedure TRegistryEdit.SetRootKey(RootKey: TRootKey);
begin
  FRootKey := RootKey;
  case RootKey of
    rkClassesRoot  : FRegistryKey := HKEY_CLASSES_ROOT;
    rkCurrentUser  : FRegistryKey := HKEY_CURRENT_USER;
    rkLocalMachine : FRegistryKey := HKEY_LOCAL_MACHINE;
    rkAllUsers     : FRegistryKey := HKEY_USERS;
    rkCurrentConfig: FRegistryKey := HKEY_CURRENT_CONFIG;
    rkDynData      : FRegistryKey := HKEY_DYN_DATA;
  end;
end;

procedure TRegistryEdit.WriteString(DataName: string; DataValue: string);
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Reg.OpenKey(FRegKey, True);
  Reg.WriteString(DataName, DataValue);
  Reg.CloseKey;
  Reg.Free;
end;

procedure TRegistryEdit.WriteInteger(DataName: string; DataValue: integer);
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Reg.OpenKey(FRegKey, True);
  Reg.WriteInteger(DataName, DataValue);
  Reg.CloseKey;
  Reg.Free;
end;

procedure TRegistryEdit.WriteBoolean(DataName: string; DataValue: boolean);
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Reg.OpenKey(FRegKey, True);
  Reg.WriteBool(DataName, DataValue);
  Reg.CloseKey;
  Reg.Free;
end;

procedure TRegistryEdit.WriteDateTime(DataName: string; DataValue: TDateTime);
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Reg.OpenKey(FRegKey, True);
  Reg.WriteDateTime(DataName, DataValue);
  Reg.CloseKey;
  Reg.Free;
end;

function TRegistryEdit.ReadString(DataName: string; Default: string): string;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  if not Reg.OpenKey(FRegKey, False) then
    Result := Default
  else
  begin
    Result := Reg.ReadString(DataName);
    Reg.CloseKey;
  end;
  Reg.Free;
end;

function TRegistryEdit.ReadInteger(DataName: string; Default: integer): integer;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  if not Reg.OpenKey(FRegKey, False) then
    Result := Default
  else
  begin
    Result := Reg.ReadInteger(DataName);
    Reg.CloseKey;
  end;
  Reg.Free;
end;

function TRegistryEdit.ReadDateTime(DataName: string; Default: TDateTime): TDateTime;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  if not Reg.OpenKey(FRegKey, False) then
    Result := Default
  else
  begin
    Result := Reg.ReadDateTime(DataName);
    Reg.CloseKey;
  end;
  Reg.Free;
end;

function TRegistryEdit.ReadBoolean(DataName: string; Default: boolean): boolean;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  if not Reg.OpenKey(FRegKey, False) then
    Result := Default
  else
  begin
    Result := Reg.ReadBool(DataName);
    Reg.CloseKey;
  end;
  Reg.Free;
end;

function TRegistryEdit.DeleteKey(Key: string): boolean;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Result := Reg.DeleteKey(Key);
  Reg.Free;
end;

function TRegistryEdit.DeleteDataValue(DataValue: string): boolean;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Result := Reg.DeleteValue(FRegKey + DataValue);
  Reg.Free;
end;

function TRegistryEdit.KeyExists(Key: string): boolean;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  Result := Reg.KeyExists(Key);
  Reg.Free;
end;

function TRegistryEdit.DataValueExists(DataValue: string): boolean;
var Reg: TRegistry;
begin
  Reg := TRegistry.Create;
  Reg.RootKey := FRegistryKey;
  if Reg.OpenKey(FRegKey, False) then
    Result := Reg.ValueExists(DataValue)
  else
    Result := False;
  Reg.Free;
end;

end.
